<?php
/*
Plugin Name: WU - Get Avatar from CDN
Plugin URI: http://wolf-u.li/4188/
Description: Gets the Gravatar-Avatar from the CDN
Version: 1.0
Author: Uli Wolf
Author URI: http://wolf-u.li
*/

/**
 * Retrieve the avatar for a user who provided a user ID or email address.
 *
 * @param int|string|object $id_or_email A user ID,  email address, or comment object
 * @param int $size Size of the avatar image
 * @param string $default URL to a default image to use if no avatar is available
 * @param string $alt Alternate text to use in image tag. Defaults to blank
 * @return string <img> tag for the user's avatar
 */
function wu_get_avatar($avatar, $id_or_email, $size = 33, $default = "", $alt = "") {
        // Add the string to your local cache here. Please remove http://
        // or https:// as these will be recognized automatically
        // If your Gravatars are located under:
        //      http://img.yourdomain.tld/g/32/a9ec4695d424a6dcb6f896afb0ee22bc.png
        // then the url is:
        //      img.yourdomain.tld/g/
        $cdnurl="img.yourdomain.tld/g/";

        // Don't change anything below
        // Validate E-Mail
        if ( is_numeric($id_or_email) ) {
                $id = (int) $id_or_email;
                $user = get_userdata($id);
                if ( $user )
                        $email = $user->user_email;
        } elseif ( is_object($id_or_email) ) {
                // No avatar for pingbacks or trackbacks
                $allowed_comment_types = apply_filters( 'get_avatar_comment_types', array( 'comment' ) );
                if ( ! empty( $id_or_email->comment_type ) && ! in_array( $id_or_email->comment_type, (array) $allowed_comment_types ) )
                        return false;
                if ( !empty($id_or_email->user_id) ) {
                        $id = (int) $id_or_email->user_id;
                        $user = get_userdata($id);
                        if ( $user)
                                $email = $user->user_email;
                } elseif ( !empty($id_or_email->comment_author_email) ) {
                        $email = $id_or_email->comment_author_email;
                }
        } else {
                $email = $id_or_email;
        }
        if ( !empty($email) )
        $email_hash = md5( strtolower( $email ) );
        if ( is_ssl() ) {
                $http = "https://";
        } else {
                $http = "http://";
        }
        $out = $http . $cdnurl . $size . "/" . $email_hash . ".png";
        return "<img alt='{$alt}' src='{$out}' class='avatar avatar-{$size} photo' height='{$size}' width='{$size}' />";
}

add_filter('get_avatar', 'wu_get_avatar',10,4);
?>